@@ -2,7 +2,7 @@
 use strict;
 use warnings;
 package Dist::Zilla::PluginBundle::HARTZELL;
-$Dist::Zilla::PluginBundle::HARTZELL::VERSION = '0.010';
+$Dist::Zilla::PluginBundle::HARTZELL::VERSION = '0.011';
 # ABSTRACT: My standard dzil config.
 
 
@@ -128,7 +128,7 @@ sub configure {
                      # gather and prune
                      # skip things that are also already in the build dir
                      [ 'Git::GatherDir' =>
-                       { exclude_filename => [qw/README.pod META.json cpanfile/] }], # core
+                       { exclude_filename => [qw/README.pod META.json/] }], # core
                      'PruneCruft',         # core
                      'ManifestSkip',       # core
 
@@ -253,7 +253,7 @@ Dist::Zilla::PluginBundle::HARTZELL - My standard dzil config.
 
 =head1 VERSION
 
-version 0.010
+version 0.011
 
 =head1 SYNOPSIS
 
@@ -285,7 +285,6 @@ dist.ini:
    [Git::GatherDir]         ; everything from git ls-files
    exclude_filename = README.pod   ; skip this generated file
    exclude_filename = META.json    ; skip this generated file
-   exclude_filename = cpanfile     ; skip this generated file
  
    [PruneCruft]        ; default stuff to skip
    [ManifestSkip]      ; if -f MANIFEST.SKIP, skip those, too
